/* SPDX-License-Identifier: MIT
 * Small Data Compression Library
 * Copyright (c) 2020 Kingizor */

#ifndef SD_COMP
#define SD_COMP

#include <stddef.h>

/* All compression and decompression functions listed here return 0 if they
   complete successfully, or 1 if an error is encountered.
   If an error is encountered, calling sd_get_error(); will return a
   character string explaining the error.

   For compression and decompression to memory, the functions will allocate
   data necessary for the provided output pointer, which must be freed
   manually by the user.
*/


/* Error reporting */
const char *sd_get_error (void);


/* Compression functions */
int sd_compress_mem_to_mem (
    unsigned char **output,
    size_t *output_size,
    unsigned char *input,
    size_t input_size
);
int sd_compress_mem_to_file (
    const char *file_out,
    unsigned char *input,
    size_t input_size
);
int sd_compress_file_to_file (
    const char *file_out,
    const char *file_in
);
int sd_compress_file_to_mem (
    unsigned char **output,
    size_t *output_size,
    const char *file_in
);


/* Decompression functions */
int sd_decompress_mem_to_mem (
    unsigned char **output,
    size_t *output_size,
    unsigned char *input,
    size_t input_size
);
int sd_decompress_mem_to_file (
    const char *file_out,
    unsigned char *input,
    size_t input_size
);
int sd_decompress_file_to_mem (
    unsigned char **output,
    size_t *output_size,
    const char *file_in,
    size_t file_position
);
int sd_decompress_file_to_file (
    const char *file_out,
    const char *file_in,
    size_t position
);

#endif
